"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.generate = void 0;
const tslib_1 = require("tslib");
const fast_glob_1 = tslib_1.__importDefault(require("fast-glob"));
const fs_extra_1 = require("fs-extra");
const string_util_1 = require("@kubernetes-models/string-util");
const path_1 = require("path");
const ignore_1 = tslib_1.__importDefault(require("ignore"));
const path_2 = require("path");
const CJS_EXT = ".js";
const ESM_EXT = ".mjs";
async function generate({ cwd = process.cwd(), include = ["**/*.ts"], exclude = [], export: exportPath, ignoreFile = (0, path_2.join)(cwd, ".export-map-ignore") }) {
    const ig = (0, ignore_1.default)();
    ig.add(exclude);
    if (await (0, fs_extra_1.pathExists)(ignoreFile)) {
        ig.add(await (0, fs_extra_1.readFile)(ignoreFile, "utf-8"));
    }
    const paths = await (0, fast_glob_1.default)(include, {
        cwd
    });
    paths.sort();
    const exportMap = {};
    for (const path of paths) {
        if (ig.ignores(path))
            continue;
        const base = (0, string_util_1.trimSuffix)(path, (0, path_1.extname)(path));
        const exportPath = base === "index" ? "." : `./${(0, string_util_1.trimSuffix)(base, "/index")}`;
        const requirePath = `./${base}${CJS_EXT}`;
        const importPath = `./${base}${ESM_EXT}`;
        exportMap[exportPath] = {
            require: requirePath,
            import: importPath
        };
    }
    await (0, fs_extra_1.writeJSON)(exportPath, exportMap, {
        spaces: 2
    });
    console.log("Generated export map in %s", exportPath);
}
exports.generate = generate;
//# sourceMappingURL=generate.js.map